@@ -12,7 +12,7 @@ with D.html():
         D.title()("foo")
     with D.body():
         with D.h1(id="foo"):
-	    D._text("This is a <foo> & test")
+            D._text("This is a <foo> & test")
         with D.table(_class="cool"):
             with D.tbody():
                 for row in range(1,3):
@@ -60,8 +60,8 @@ This is a &lt;foo&gt; &amp; test
 """
 
 if str(D) == expected:
-    print "YAY"
+    print("YAY")
 else:
-    print "FAIL"
-    print str(D)
+    print("FAIL")
+    print(str(D))
     exit(1)	
